@@ -6,27 +6,7 @@ use LWP::UserAgent;
 use URI::Escape;
 use Data::Util qw(:check :validate);
 
-use Catmandu::AlephX::Op::ItemData;
-use Catmandu::AlephX::Op::ItemDataMulti;
-use Catmandu::AlephX::Op::ReadItem;
-use Catmandu::AlephX::Op::Find;
-use Catmandu::AlephX::Op::FindDoc;
-use Catmandu::AlephX::Op::Present;
-use Catmandu::AlephX::Op::IllLoanInfo;
-use Catmandu::AlephX::Op::IllGetDocShort;
-use Catmandu::AlephX::Op::BorAuth;
-use Catmandu::AlephX::Op::BorInfo;
-use Catmandu::AlephX::Op::IllBorInfo;
-use Catmandu::AlephX::Op::CircStatus;
-use Catmandu::AlephX::Op::CircStatM;
-use Catmandu::AlephX::Op::PublishAvail;
-use Catmandu::AlephX::Op::IllGetDoc;
-use Catmandu::AlephX::Op::Renew;
-use Catmandu::AlephX::Op::HoldReq;
-use Catmandu::AlephX::Op::HoldReqCancel;
-
-our $VERSION = "1.03";
-
+our $VERSION = "1.05";
 
 has url => (
   is => 'ro',
@@ -152,6 +132,7 @@ For each of the document's items it retrieves:
 =cut
 sub item_data {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::ItemData;
   $args{'op'} = Catmandu::AlephX::Op::ItemData->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::ItemData->parse($res->content_ref());    
@@ -187,6 +168,7 @@ It is similar to the item_data X-service, except for the parameter START_POINT,
 =cut
 sub item_data_multi {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::ItemDataMulti;
   $args{'op'} = Catmandu::AlephX::Op::ItemDataMulti->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::ItemDataMulti->parse($res->content_ref());    
@@ -216,6 +198,7 @@ sub item_data_multi {
 
 sub read_item {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::ReadItem;
   $args{'op'} = Catmandu::AlephX::Op::ReadItem->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::ReadItem->parse($res->content_ref());    
@@ -249,6 +232,7 @@ sub read_item {
 =cut
 sub find {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::Find;
   $args{'op'} = Catmandu::AlephX::Op::Find->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::Find->parse($res->content_ref());    
@@ -278,6 +262,7 @@ sub find {
 =cut
 sub find_doc {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::FindDoc;
   $args{'op'} = Catmandu::AlephX::Op::FindDoc->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::FindDoc->parse($res->content_ref());    
@@ -313,6 +298,7 @@ sub find_doc {
 =cut
 sub present {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::Present;
   $args{'op'} = Catmandu::AlephX::Op::Present->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::Present->parse($res->content_ref());    
@@ -341,7 +327,8 @@ sub present {
 
 =cut
 sub ill_get_doc_short {
-  my($self,%args)=@_;
+  my($self,%args)=@_; 
+  require Catmandu::AlephX::Op::IllGetDocShort;
   $args{'op'} = Catmandu::AlephX::Op::IllGetDocShort->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::IllGetDocShort->parse($res->content_ref());    
@@ -380,6 +367,7 @@ sub ill_get_doc_short {
 =cut
 sub bor_auth {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::BorAuth;
   $args{'op'} = Catmandu::AlephX::Op::BorAuth->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::BorAuth->parse($res->content_ref());
@@ -430,6 +418,7 @@ sub bor_auth {
 =cut
 sub bor_info {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::BorInfo;
   $args{'op'} = Catmandu::AlephX::Op::BorInfo->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::BorInfo->parse($res->content_ref());
@@ -446,6 +435,7 @@ sub bor_info {
 =cut
 sub ill_bor_info {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::IllBorInfo;
   $args{'op'} = Catmandu::AlephX::Op::IllBorInfo->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::IllBorInfo->parse($res->content_ref());
@@ -453,6 +443,7 @@ sub ill_bor_info {
 
 sub ill_loan_info {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::IllLoanInfo;
   $args{'op'} = Catmandu::AlephX::Op::IllLoanInfo->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::IllLoanInfo->parse($res->content_ref());
@@ -472,6 +463,7 @@ The service retrieves the circulation status for each document number entered by
 =cut
 sub circ_status {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::CircStatus;
   $args{'op'} = Catmandu::AlephX::Op::CircStatus->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::CircStatus->parse($res->content_ref());
@@ -493,6 +485,7 @@ This service is similar to circ-status X-service, except for the parameter START
 =cut
 sub circ_stat_m {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::CircStatM;
   $args{'op'} = Catmandu::AlephX::Op::CircStatM->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::CircStatM->parse($res->content_ref());
@@ -536,6 +529,7 @@ if($publish->is_success){
 =cut
 sub publish_avail {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::PublishAvail;
   $args{'op'} = Catmandu::AlephX::Op::PublishAvail->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::PublishAvail->parse($res->content_ref());
@@ -565,6 +559,7 @@ if($illgetdoc->is_success){
 =cut
 sub ill_get_doc {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::IllGetDoc;
   $args{'op'} = Catmandu::AlephX::Op::IllGetDoc->op();
   my $res = $self->_do_web_request(\%args);
   Catmandu::AlephX::Op::IllGetDoc->parse($res->content_ref());
@@ -581,9 +576,10 @@ sub ill_get_doc {
 =cut
 sub renew {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::Renew;
   $args{'op'} = Catmandu::AlephX::Op::Renew->op();
   my $res = $self->_do_web_request(\%args);
-  Catmandu::Alephx::Op::Renew->parse($res->content_ref());
+  Catmandu::AlephX::Op::Renew->parse($res->content_ref());
 }
 =head2 hold_req
 
@@ -596,16 +592,26 @@ The service creates a hold-request record (Z37) for a given item after performin
 =cut
 sub hold_req {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::HoldReq;
   $args{'op'} = Catmandu::AlephX::Op::HoldReq->op();
   my $res = $self->_do_web_request(\%args);
-  Catmandu::Alephx::Op::HoldReq->parse($res->content_ref());
+  Catmandu::AlephX::Op::HoldReq->parse($res->content_ref());
 }
 sub hold_req_cancel {
   my($self,%args)=@_;
+  require Catmandu::AlephX::Op::HoldReqCancel;
   $args{'op'} = Catmandu::AlephX::Op::HoldReqCancel->op();
   my $res = $self->_do_web_request(\%args);
-  Catmandu::Alephx::Op::HoldReqCancel->parse($res->content_ref());
+  Catmandu::AlephX::Op::HoldReqCancel->parse($res->content_ref());
 }
+sub user_auth {
+  my($self,%args)=@_;
+  require Catmandu::AlephX::Op::UserAuth;
+  $args{op} = Catmandu::AlephX::Op::UserAuth->op();
+  my $res = $self->_do_web_request(\%args);
+  Catmandu::AlephX::Op::UserAuth->parse($res->content_ref());
+}
+
 =head1 AUTHOR
 
 Nicolas Franck, C<< <nicolas.franck at ugent.be> >>
